# Generated by Django 3.2.8 on 2022-01-09 10:19

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0063_notification_verification'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='note_text',
            field=models.ForeignKey(blank=True, default=None, null=True,
                                    on_delete=django.db.models.deletion.CASCADE, to='corptools.notificationtext'),
        ),
    ]
