# Generated by Django 4.0.2 on 2022-08-06 11:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0074_evelocation_managed_evelocation_managed_char_and_more'),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name='notification',
            name='corptools_n_notific_77c7f2_idx',
        ),
    ]
