# Generated by Django 3.1.1 on 2021-01-14 09:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0041_auto_20210112_1359'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='skilllist',
            name='eft',
        ),
    ]
