# Generated by Django 4.2.16 on 2025-04-05 09:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0118_alter_skill_id'),
    ]

    operations = [
        migrations.CreateModel(
            name='CharacterAgeFilter',
            fields=[
                ('id', models.AutoField(auto_created=True,
                 primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=500)),
                ('description', models.CharField(max_length=500)),
                ('min_age', models.IntegerField(default=30)),
                ('reversed_logic', models.BooleanField(default=False,
                 help_text='If set all user with age less than the min_max_age will pass the test.')),
            ],
            options={
                'verbose_name': 'Smart Filter: Character Age Filter',
                'verbose_name_plural': 'Smart Filter: Character Age Filter',
            },
        ),
    ]
