# Generated by Django 4.2.16 on 2025-04-08 09:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0119_characteragefilter'),
    ]

    operations = [
        migrations.AddField(
            model_name='corptoolsconfiguration',
            name='aggregate_lookback',
            field=models.IntegerField(
                default=90, help_text='Days to look back in aggregated views, like the mining ledger graphs.'),
        ),
    ]
