# Generated by Django 2.2.12 on 2020-05-24 15:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0013_eveitemdogmaattribute'),
    ]

    operations = [
        migrations.AddField(
            model_name='characteraudit',
            name='balance',
            field=models.DecimalField(
                decimal_places=2, default=None, max_digits=20, null=True),
        ),
    ]
