# Generated by Django 4.0.8 on 2023-02-24 09:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0083_skilltotalhistory'),
    ]

    operations = [
        migrations.AddField(
            model_name='characteraudit',
            name='last_update_loyaltypoints',
            field=models.DateTimeField(blank=True, default=None, null=True),
        ),
        migrations.CreateModel(
            name='LoyaltyPoint',
            fields=[
                ('id', models.AutoField(auto_created=True,
                 primary_key=True, serialize=False, verbose_name='ID')),
                ('amount', models.IntegerField(verbose_name='LP')),
                ('character', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE,
                 to='corptools.characteraudit', verbose_name='Character')),
                ('corporation', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE,
                 to='corptools.evename', verbose_name='NPC Corporation')),
            ],
            options={
                'verbose_name': 'Loyalty Point',
                'unique_together': {('character', 'corporation')},
            },
        ),
    ]
