# Generated by Django 4.2.16 on 2025-03-07 09:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0116_starbase'),
    ]

    operations = [
        migrations.AddField(
            model_name='starbase',
            name='name',
            field=models.CharField(
                blank=True, default='', max_length=255, null=True),
        ),
    ]
