# Generated by Django 4.0.8 on 2023-02-01 09:18

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0082_characteraudit_last_update_contracts_contract_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='SkillTotalHistory',
            fields=[
                ('id', models.AutoField(auto_created=True,
                 primary_key=True, serialize=False, verbose_name='ID')),
                ('date', models.DateTimeField(auto_now=True)),
                ('total_sp', models.BigIntegerField()),
                ('unallocated_sp', models.IntegerField(default=0)),
                ('character', models.ForeignKey(
                    on_delete=django.db.models.deletion.CASCADE, to='corptools.characteraudit')),
            ],
        ),
    ]
