{% load i18n %}
<li class="nav-item">
    <a class="nav-link" href="{% url 'corptools:react' %}">{% translate "Character Audit" %}</a>
</li>
<li class="nav-item">
    <a class="nav-link" href="{% url 'corptools:corp_react' %}">{% translate "Corporate Audit" %}</a>
</li>
