.strikeOut {
  display: flex;
  flex-direction: row;
  justify-content: center;
  margin: 0;
}

.strikeOut:before {
  content: "";
  width: 150px !important;
  border-bottom: 1px solid var(--bs-border-color);
  margin-top: auto;
  margin-bottom: auto;
  margin-right: 10px !important;
  margin-left: 10px !important;
}

.strikeOut:after {
  content: "";
  width: 150px !important;
  border-bottom: 1px solid var(--bs-border-color);
  margin-top: auto;
  margin-bottom: auto;
  margin-right: 10px !important;
  margin-left: 10px !important;
}
