.menuRefreshSpin {
  -animation: spin 2s infinite linear;
  -ms-animation: spin 2s infinite linear;
  -webkit-animation: spin 2s infinite linear;
  -moz-animation: spin 2s infinite linear;
}

@keyframes spin {
  from {
    transform: rotate(0deg);
  }
  to {
    transform: rotate(359deg);
  }
}
