# Generated by Django 4.2.4 on 2023-08-02 22:59

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0089_highestspfilter'),
    ]

    operations = [
        migrations.RenameField(
            model_name='corporationaudit',
            old_name='cache_expire_assets',
            new_name='last_change_assets',
        ),
        migrations.RenameField(
            model_name='corporationaudit',
            old_name='cache_expire_moons',
            new_name='last_change_moons',
        ),
        migrations.RenameField(
            model_name='corporationaudit',
            old_name='cache_expire_observers',
            new_name='last_change_observers',
        ),
        migrations.RenameField(
            model_name='corporationaudit',
            old_name='cache_expire_pub_data',
            new_name='last_change_pub_data',
        ),
        migrations.RenameField(
            model_name='corporationaudit',
            old_name='cache_expire_structures',
            new_name='last_change_structures',
        ),
        migrations.RenameField(
            model_name='corporationaudit',
            old_name='cache_expire_wallet',
            new_name='last_change_wallet',
        ),
    ]
