# Generated by Django 4.2.5 on 2023-10-02 11:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('corptools', '0094_lastloginfilter_characteraudit_last_known_login_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='lastloginfilter',
            name='main_corp_only',
            field=models.BooleanField(
                blank=True, default=False, help_text="Only check characters in main's corporation."),
        ),
        migrations.AlterField(
            model_name='lastloginfilter',
            name='days_since_login',
            field=models.IntegerField(
                default=30, help_text='Days since last login of any Character in the accounts before failing the filter.'),
        ),
    ]
